==> webpdf-wsclient-10.0.0-sources.jar: net/webpdf/wsclient/schema/operation/HeaderFooterType.java <==

package net.webpdf.wsclient.schema.operation;

import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlAttribute;
import jakarta.xml.bind.annotation.XmlType;


/**
 * <pre>
 * &lt;?xml version="1.0" encoding="UTF-8"?&gt;&lt;p xmlns:p112675_="urn:jaxb.jvnet.org:plugin:inheritance" xmlns:p263167_="https://jakarta.ee/xml/ns/jaxb" xmlns:p878401_="urn:jaxb.jvnet.org:plugin:simplify" xmlns:tns="http://schema.webpdf.de/1.0/operation" xmlns:xs="http://www.w3.org/2001/XMLSchema"&gt;Used to define the header and footer that will be added to a document.&lt;/p&gt;
 * </pre>
 * 
 * <p>Java class for HeaderFooterType complex type</p>.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.</p>
 * 
 * <pre>{@code
 * <complexType name="HeaderFooterType">
 *   <complexContent>
 *     <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       <all>
 *         <element name="pages" minOccurs="0">
 *           <complexType>
 *             <complexContent>
 *               <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *                 <choice>
 *                   <element name="pageInterval" type="{http://schema.webpdf.de/1.0/operation}PageIntervalType" minOccurs="0"/>
 *                 </choice>
 *               </restriction>
 *             </complexContent>
 *           </complexType>
 *         </element>
 *         <element name="margin" type="{http://schema.webpdf.de/1.0/operation}OptionsMarginType" minOccurs="0"/>
 *         <element name="font" type="{http://schema.webpdf.de/1.0/operation}OptionsFontType" minOccurs="0"/>
 *         <element name="header" type="{http://schema.webpdf.de/1.0/operation}HeaderFooterPositionsType" minOccurs="0"/>
 *         <element name="footer" type="{http://schema.webpdf.de/1.0/operation}HeaderFooterPositionsType" minOccurs="0"/>
 *         <element name="date" type="{http://schema.webpdf.de/1.0/operation}HeaderFooterDate" minOccurs="0"/>
 *       </all>
 *       <attribute name="firstPageNumber" default="1">
 *         <simpleType>
 *           <restriction base="{http://www.w3.org/2001/XMLSchema}int">
 *             <minInclusive value="1"/>
 *           </restriction>
 *         </simpleType>
 *       </attribute>
 *       <attribute name="replaceExisting" type="{http://www.w3.org/2001/XMLSchema}boolean" default="false" />
 *     </restriction>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "HeaderFooterType", propOrder = {

})
public class HeaderFooterType {

    /**
     * <pre>
     * &lt;?xml version="1.0" encoding="UTF-8"?&gt;&lt;p xmlns:p112675_="urn:jaxb.jvnet.org:plugin:inheritance" xmlns:p263167_="https://jakarta.ee/xml/ns/jaxb" xmlns:p878401_="urn:jaxb.jvnet.org:plugin:simplify" xmlns:tns="http://schema.webpdf.de/1.0/operation" xmlns:xs="http://www.w3.org/2001/XMLSchema"&gt;Selects the pages, to which header/footer elements shall be applied.&lt;/p&gt;
     * </pre>
     * 
     */
    protected HeaderFooterType.Pages pages;
    protected OptionsMarginType margin;
    protected OptionsFontType font;
    protected HeaderFooterPositionsType header;
    protected HeaderFooterPositionsType footer;
    protected HeaderFooterDate date;
    /**
     * <pre>
     * &lt;?xml version="1.0" encoding="UTF-8"?&gt;&lt;p xmlns:p112675_="urn:jaxb.jvnet.org:plugin:inheritance" xmlns:p263167_="https://jakarta.ee/xml/ns/jaxb" xmlns:p878401_="urn:jaxb.jvnet.org:plugin:simplify" xmlns:tns="http://schema.webpdf.de/1.0/operation" xmlns:xs="http://www.w3.org/2001/XMLSchema"&gt;Used to specify the starting page for page number formats.&lt;/p&gt;
     * </pre>
     * 
     */
    @XmlAttribute(name = "firstPageNumber")
    protected Integer firstPageNumber;
    /**
     * <pre>
     * &lt;?xml version="1.0" encoding="UTF-8"?&gt;&lt;p xmlns:p112675_="urn:jaxb.jvnet.org:plugin:inheritance" xmlns:p263167_="https://jakarta.ee/xml/ns/jaxb" xmlns:p878401_="urn:jaxb.jvnet.org:plugin:simplify" xmlns:tns="http://schema.webpdf.de/1.0/operation" xmlns:xs="http://www.w3.org/2001/XMLSchema"&gt;If true, preexisting header and footer definition will be automatically deleted from all pages of the document and replaced with the new one. If false, preexisting header and footer definitions on any page of the document will cause the operation to be aborted.&lt;/p&gt;
     * </pre>
     * 
     */
    @XmlAttribute(name = "replaceExisting")
    protected Boolean replaceExisting;

    /**
     * <pre>
     * &lt;?xml version="1.0" encoding="UTF-8"?&gt;&lt;p xmlns:p112675_="urn:jaxb.jvnet.org:plugin:inheritance" xmlns:p263167_="https://jakarta.ee/xml/ns/jaxb" xmlns:p878401_="urn:jaxb.jvnet.org:plugin:simplify" xmlns:tns="http://schema.webpdf.de/1.0/operation" xmlns:xs="http://www.w3.org/2001/XMLSchema"&gt;Selects the pages, to which header/footer elements shall be applied.&lt;/p&gt;
     * </pre>
     * 
     * @return
     *     possible object is
     *     {@link HeaderFooterType.Pages }
     *     
     */
    public HeaderFooterType.Pages getPages() {
        return pages;
    }

    /**
     * Sets the value of the pages property.
     * 
     * @param value
     *     allowed object is
     *     {@link HeaderFooterType.Pages }
     *     
     * @see #getPages()
     */
    public void setPages(HeaderFooterType.Pages value) {
        this.pages = value;
    }

    public boolean isSetPages() {
        return (this.pages!= null);
    }

    /**
     * Gets the value of the margin property.
     * 
     * @return
     *     possible object is
     *     {@link OptionsMarginType }
     *     
     */
    public OptionsMarginType getMargin() {
        return margin;
    }

    /**
     * Sets the value of the margin property.
     * 
     * @param value
     *     allowed object is
     *     {@link OptionsMarginType }
     *     
     */
    public void setMargin(OptionsMarginType value) {
        this.margin = value;
    }

    public boolean isSetMargin() {
        return (this.margin!= null);
    }

    /**
     * Gets the value of the font property.
     * 
     * @return
     *     possible object is
     *     {@link OptionsFontType }
     *     
     */
    public OptionsFontType getFont() {
        return font;
    }

    /**
     * Sets the value of the font property.
     * 
     * @param value
     *     allowed object is
     *     {@link OptionsFontType }
     *     
     */
    public void setFont(OptionsFontType value) {
        this.font = value;
    }

    public boolean isSetFont() {
        return (this.font!= null);
    }

    /**
     * Gets the value of the header property.
     * 
     * @return
     *     possible object is
     *     {@link HeaderFooterPositionsType }
     *     
     */
    public HeaderFooterPositionsType getHeader() {
        return header;
    }

    /**
     * Sets the value of the header property.
     * 
     * @param value
     *     allowed object is
     *     {@link HeaderFooterPositionsType }
     *     
     */
    public void setHeader(HeaderFooterPositionsType value) {
        this.header = value;
    }

    public boolean isSetHeader() {
        return (this.header!= null);
    }

    /**
     * Gets the value of the footer property.
     * 
     * @return
     *     possible object is
     *     {@link HeaderFooterPositionsType }
     *     
     */
    public HeaderFooterPositionsType getFooter() {
        return footer;
    }

    /**
     * Sets the value of the footer property.
     * 
     * @param value
     *     allowed object is
     *     {@link HeaderFooterPositionsType }
     *     
     */
    public void setFooter(HeaderFooterPositionsType value) {
        this.footer = value;
    }

    public boolean isSetFooter() {
        return (this.footer!= null);
    }

    /**
     * Gets the value of the date property.
     * 
     * @return
     *     possible object is
     *     {@link HeaderFooterDate }
     *     
     */
    public HeaderFooterDate getDate() {
        return date;
    }

    /**
     * Sets the value of the date property.
     * 
     * @param value
     *     allowed object is
     *     {@link HeaderFooterDate }
     *     
     */
    public void setDate(HeaderFooterDate value) {
        this.date = value;
    }

    public boolean isSetDate() {
        return (this.date!= null);
    }

    /**
     * <pre>
     * &lt;?xml version="1.0" encoding="UTF-8"?&gt;&lt;p xmlns:p112675_="urn:jaxb.jvnet.org:plugin:inheritance" xmlns:p263167_="https://jakarta.ee/xml/ns/jaxb" xmlns:p878401_="urn:jaxb.jvnet.org:plugin:simplify" xmlns:tns="http://schema.webpdf.de/1.0/operation" xmlns:xs="http://www.w3.org/2001/XMLSchema"&gt;Used to specify the starting page for page number formats.&lt;/p&gt;
     * </pre>
     * 
     * @return
     *     possible object is
     *     {@link Integer }
     *     
     */
    public int getFirstPageNumber() {
        if (firstPageNumber == null) {
            return  1;
        } else {
            return firstPageNumber;
        }
    }

    /**
     * Sets the value of the firstPageNumber property.
     * 
     * @param value
     *     allowed object is
     *     {@link Integer }
     *     
     * @see #getFirstPageNumber()
     */
    public void setFirstPageNumber(int value) {
        this.firstPageNumber = value;
    }

    public boolean isSetFirstPageNumber() {
        return (this.firstPageNumber!= null);
    }

    public void unsetFirstPageNumber() {
        this.firstPageNumber = null;
    }

    /**
     * <pre>
     * &lt;?xml version="1.0" encoding="UTF-8"?&gt;&lt;p xmlns:p112675_="urn:jaxb.jvnet.org:plugin:inheritance" xmlns:p263167_="https://jakarta.ee/xml/ns/jaxb" xmlns:p878401_="urn:jaxb.jvnet.org:plugin:simplify" xmlns:tns="http://schema.webpdf.de/1.0/operation" xmlns:xs="http://www.w3.org/2001/XMLSchema"&gt;If true, preexisting header and footer definition will be automatically deleted from all pages of the document and replaced with the new one. If false, preexisting header and footer definitions on any page of the document will cause the operation to be aborted.&lt;/p&gt;
     * </pre>
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public boolean isReplaceExisting() {
        if (replaceExisting == null) {
            return false;
        } else {
            return replaceExisting;
        }
    }

    /**
     * Sets the value of the replaceExisting property.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     * @see #isReplaceExisting()
     */
    public void setReplaceExisting(boolean value) {
        this.replaceExisting = value;
    }

    public boolean isSetReplaceExisting() {
        return (this.replaceExisting!= null);
    }

    public void unsetReplaceExisting() {
        this.replaceExisting = null;
    }


    /**
     * <p>Java class for anonymous complex type</p>.
     * 
     * <p>The following schema fragment specifies the expected content contained within this class.</p>
     * 
     * <pre>{@code
     * <complexType>
     *   <complexContent>
     *     <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
     *       <choice>
     *         <element name="pageInterval" type="{http://schema.webpdf.de/1.0/operation}PageIntervalType" minOccurs="0"/>
     *       </choice>
     *     </restriction>
     *   </complexContent>
     * </complexType>
     * }</pre>
     * 
     * 
     */
    @XmlAccessorType(XmlAccessType.FIELD)
    @XmlType(name = "", propOrder = {
        "pageInterval"
    })
    public static class Pages {

        protected PageIntervalType pageInterval;

        /**
         * Gets the value of the pageInterval property.
         * 
         * @return
         *     possible object is
         *     {@link PageIntervalType }
         *     
         */
        public PageIntervalType getPageInterval() {
            return pageInterval;
        }

        /**
         * Sets the value of the pageInterval property.
         * 
         * @param value
         *     allowed object is
         *     {@link PageIntervalType }
         *     
         */
        public void setPageInterval(PageIntervalType value) {
            this.pageInterval = value;
        }

        public boolean isSetPageInterval() {
            return (this.pageInterval!= null);
        }

    }

}

==> webpdf-wsclient-10.0.1-sources.jar: net/webpdf/wsclient/schema/operation/HeaderFooterType.java <==

package net.webpdf.wsclient.schema.operation;

import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlAttribute;
import jakarta.xml.bind.annotation.XmlType;


/**
 * <pre>
 * &lt;?xml version="1.0" encoding="UTF-8"?&gt;&lt;p xmlns:p490833_="urn:jaxb.jvnet.org:plugin:simplify" xmlns:p603985_="urn:jaxb.jvnet.org:plugin:inheritance" xmlns:p985611_="https://jakarta.ee/xml/ns/jaxb" xmlns:tns="http://schema.webpdf.de/1.0/operation" xmlns:xs="http://www.w3.org/2001/XMLSchema"&gt;Used to define the header and footer that will be added to a document.&lt;/p&gt;
 * </pre>
 * 
 * <p>Java class for HeaderFooterType complex type</p>.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.</p>
 * 
 * <pre>{@code
 * <complexType name="HeaderFooterType">
 *   <complexContent>
 *     <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       <all>
 *         <element name="pages" minOccurs="0">
 *           <complexType>
 *             <complexContent>
 *               <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *                 <choice>
 *                   <element name="pageInterval" type="{http://schema.webpdf.de/1.0/operation}PageIntervalType" minOccurs="0"/>
 *                 </choice>
 *               </restriction>
 *             </complexContent>
 *           </complexType>
 *         </element>
 *         <element name="margin" type="{http://schema.webpdf.de/1.0/operation}OptionsMarginType" minOccurs="0"/>
 *         <element name="font" type="{http://schema.webpdf.de/1.0/operation}OptionsFontType" minOccurs="0"/>
 *         <element name="header" type="{http://schema.webpdf.de/1.0/operation}HeaderFooterPositionsType" minOccurs="0"/>
 *         <element name="footer" type="{http://schema.webpdf.de/1.0/operation}HeaderFooterPositionsType" minOccurs="0"/>
 *         <element name="date" type="{http://schema.webpdf.de/1.0/operation}HeaderFooterDate" minOccurs="0"/>
 *       </all>
 *       <attribute name="firstPageNumber" default="1">
 *         <simpleType>
 *           <restriction base="{http://www.w3.org/2001/XMLSchema}int">
 *             <minInclusive value="1"/>
 *           </restriction>
 *         </simpleType>
 *       </attribute>
 *       <attribute name="replaceExisting" type="{http://www.w3.org/2001/XMLSchema}boolean" default="false" />
 *     </restriction>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "HeaderFooterType", propOrder = {

})
public class HeaderFooterType {

    /**
     * <pre>
     * &lt;?xml version="1.0" encoding="UTF-8"?&gt;&lt;p xmlns:p490833_="urn:jaxb.jvnet.org:plugin:simplify" xmlns:p603985_="urn:jaxb.jvnet.org:plugin:inheritance" xmlns:p985611_="https://jakarta.ee/xml/ns/jaxb" xmlns:tns="http://schema.webpdf.de/1.0/operation" xmlns:xs="http://www.w3.org/2001/XMLSchema"&gt;Selects the pages, to which header/footer elements shall be applied.&lt;/p&gt;
     * </pre>
     * 
     */
    protected HeaderFooterType.Pages pages;
    protected OptionsMarginType margin;
    protected OptionsFontType font;
    protected HeaderFooterPositionsType header;
    protected HeaderFooterPositionsType footer;
    protected HeaderFooterDate date;
    /**
     * <pre>
     * &lt;?xml version="1.0" encoding="UTF-8"?&gt;&lt;p xmlns:p490833_="urn:jaxb.jvnet.org:plugin:simplify" xmlns:p603985_="urn:jaxb.jvnet.org:plugin:inheritance" xmlns:p985611_="https://jakarta.ee/xml/ns/jaxb" xmlns:tns="http://schema.webpdf.de/1.0/operation" xmlns:xs="http://www.w3.org/2001/XMLSchema"&gt;Used to specify the starting page for page number formats.&lt;/p&gt;
     * </pre>
     * 
     */
    @XmlAttribute(name = "firstPageNumber")
    protected Integer firstPageNumber;
    /**
     * <pre>
     * &lt;?xml version="1.0" encoding="UTF-8"?&gt;&lt;p xmlns:p490833_="urn:jaxb.jvnet.org:plugin:simplify" xmlns:p603985_="urn:jaxb.jvnet.org:plugin:inheritance" xmlns:p985611_="https://jakarta.ee/xml/ns/jaxb" xmlns:tns="http://schema.webpdf.de/1.0/operation" xmlns:xs="http://www.w3.org/2001/XMLSchema"&gt;If true, preexisting header and footer definition will be automatically deleted from all pages of the document and replaced with the new one. If false, preexisting header and footer definitions on any page of the document will cause the operation to be aborted.&lt;/p&gt;
     * </pre>
     * 
     */
    @XmlAttribute(name = "replaceExisting")
    protected Boolean replaceExisting;

    /**
     * <pre>
     * &lt;?xml version="1.0" encoding="UTF-8"?&gt;&lt;p xmlns:p490833_="urn:jaxb.jvnet.org:plugin:simplify" xmlns:p603985_="urn:jaxb.jvnet.org:plugin:inheritance" xmlns:p985611_="https://jakarta.ee/xml/ns/jaxb" xmlns:tns="http://schema.webpdf.de/1.0/operation" xmlns:xs="http://www.w3.org/2001/XMLSchema"&gt;Selects the pages, to which header/footer elements shall be applied.&lt;/p&gt;
     * </pre>
     * 
     * @return
     *     possible object is
     *     {@link HeaderFooterType.Pages }
     *     
     */
    public HeaderFooterType.Pages getPages() {
        return pages;
    }

    /**
     * Sets the value of the pages property.
     * 
     * @param value
     *     allowed object is
     *     {@link HeaderFooterType.Pages }
     *     
     * @see #getPages()
     */
    public void setPages(HeaderFooterType.Pages value) {
        this.pages = value;
    }

    public boolean isSetPages() {
        return (this.pages!= null);
    }

    /**
     * Gets the value of the margin property.
     * 
     * @return
     *     possible object is
     *     {@link OptionsMarginType }
     *     
     */
    public OptionsMarginType getMargin() {
        return margin;
    }

    /**
     * Sets the value of the margin property.
     * 
     * @param value
     *     allowed object is
     *     {@link OptionsMarginType }
     *     
     */
    public void setMargin(OptionsMarginType value) {
        this.margin = value;
    }

    public boolean isSetMargin() {
        return (this.margin!= null);
    }

    /**
     * Gets the value of the font property.
     * 
     * @return
     *     possible object is
     *     {@link OptionsFontType }
     *     
     */
    public OptionsFontType getFont() {
        return font;
    }

    /**
     * Sets the value of the font property.
     * 
     * @param value
     *     allowed object is
     *     {@link OptionsFontType }
     *     
     */
    public void setFont(OptionsFontType value) {
        this.font = value;
    }

    public boolean isSetFont() {
        return (this.font!= null);
    }

    /**
     * Gets the value of the header property.
     * 
     * @return
     *     possible object is
     *     {@link HeaderFooterPositionsType }
     *     
     */
    public HeaderFooterPositionsType getHeader() {
        return header;
    }

    /**
     * Sets the value of the header property.
     * 
     * @param value
     *     allowed object is
     *     {@link HeaderFooterPositionsType }
     *     
     */
    public void setHeader(HeaderFooterPositionsType value) {
        this.header = value;
    }

    public boolean isSetHeader() {
        return (this.header!= null);
    }

    /**
     * Gets the value of the footer property.
     * 
     * @return
     *     possible object is
     *     {@link HeaderFooterPositionsType }
     *     
     */
    public HeaderFooterPositionsType getFooter() {
        return footer;
    }

    /**
     * Sets the value of the footer property.
     * 
     * @param value
     *     allowed object is
     *     {@link HeaderFooterPositionsType }
     *     
     */
    public void setFooter(HeaderFooterPositionsType value) {
        this.footer = value;
    }

    public boolean isSetFooter() {
        return (this.footer!= null);
    }

    /**
     * Gets the value of the date property.
     * 
     * @return
     *     possible object is
     *     {@link HeaderFooterDate }
     *     
     */
    public HeaderFooterDate getDate() {
        return date;
    }

    /**
     * Sets the value of the date property.
     * 
     * @param value
     *     allowed object is
     *     {@link HeaderFooterDate }
     *     
     */
    public void setDate(HeaderFooterDate value) {
        this.date = value;
    }

    public boolean isSetDate() {
        return (this.date!= null);
    }

    /**
     * <pre>
     * &lt;?xml version="1.0" encoding="UTF-8"?&gt;&lt;p xmlns:p490833_="urn:jaxb.jvnet.org:plugin:simplify" xmlns:p603985_="urn:jaxb.jvnet.org:plugin:inheritance" xmlns:p985611_="https://jakarta.ee/xml/ns/jaxb" xmlns:tns="http://schema.webpdf.de/1.0/operation" xmlns:xs="http://www.w3.org/2001/XMLSchema"&gt;Used to specify the starting page for page number formats.&lt;/p&gt;
     * </pre>
     * 
     * @return
     *     possible object is
     *     {@link Integer }
     *     
     */
    public int getFirstPageNumber() {
        if (firstPageNumber == null) {
            return  1;
        } else {
            return firstPageNumber;
        }
    }

    /**
     * Sets the value of the firstPageNumber property.
     * 
     * @param value
     *     allowed object is
     *     {@link Integer }
     *     
     * @see #getFirstPageNumber()
     */
    public void setFirstPageNumber(int value) {
        this.firstPageNumber = value;
    }

    public boolean isSetFirstPageNumber() {
        return (this.firstPageNumber!= null);
    }

    public void unsetFirstPageNumber() {
        this.firstPageNumber = null;
    }

    /**
     * <pre>
     * &lt;?xml version="1.0" encoding="UTF-8"?&gt;&lt;p xmlns:p490833_="urn:jaxb.jvnet.org:plugin:simplify" xmlns:p603985_="urn:jaxb.jvnet.org:plugin:inheritance" xmlns:p985611_="https://jakarta.ee/xml/ns/jaxb" xmlns:tns="http://schema.webpdf.de/1.0/operation" xmlns:xs="http://www.w3.org/2001/XMLSchema"&gt;If true, preexisting header and footer definition will be automatically deleted from all pages of the document and replaced with the new one. If false, preexisting header and footer definitions on any page of the document will cause the operation to be aborted.&lt;/p&gt;
     * </pre>
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public boolean isReplaceExisting() {
        if (replaceExisting == null) {
            return false;
        } else {
            return replaceExisting;
        }
    }

    /**
     * Sets the value of the replaceExisting property.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     * @see #isReplaceExisting()
     */
    public void setReplaceExisting(boolean value) {
        this.replaceExisting = value;
    }

    public boolean isSetReplaceExisting() {
        return (this.replaceExisting!= null);
    }

    public void unsetReplaceExisting() {
        this.replaceExisting = null;
    }


    /**
     * <p>Java class for anonymous complex type</p>.
     * 
     * <p>The following schema fragment specifies the expected content contained within this class.</p>
     * 
     * <pre>{@code
     * <complexType>
     *   <complexContent>
     *     <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
     *       <choice>
     *         <element name="pageInterval" type="{http://schema.webpdf.de/1.0/operation}PageIntervalType" minOccurs="0"/>
     *       </choice>
     *     </restriction>
     *   </complexContent>
     * </complexType>
     * }</pre>
     * 
     * 
     */
    @XmlAccessorType(XmlAccessType.FIELD)
    @XmlType(name = "", propOrder = {
        "pageInterval"
    })
    public static class Pages {

        protected PageIntervalType pageInterval;

        /**
         * Gets the value of the pageInterval property.
         * 
         * @return
         *     possible object is
         *     {@link PageIntervalType }
         *     
         */
        public PageIntervalType getPageInterval() {
            return pageInterval;
        }

        /**
         * Sets the value of the pageInterval property.
         * 
         * @param value
         *     allowed object is
         *     {@link PageIntervalType }
         *     
         */
        public void setPageInterval(PageIntervalType value) {
            this.pageInterval = value;
        }

        public boolean isSetPageInterval() {
            return (this.pageInterval!= null);
        }

    }

}
